**********************
Workload Configs
**********************

==============
Debug Config
==============
.. autoclass:: kubetorch.DebugConfig
   :members:

   .. automethod:: __init__

==============
Logging Config
==============
.. autoclass:: kubetorch.LoggingConfig
   :members:

   .. automethod:: __init__

==============
Metrics Config
==============
.. autoclass:: kubetorch.MetricsConfig
   :members:

   .. automethod:: __init__
